Windows Guides
``````````````

The following sections provide information on managing
Windows hosts with Ansible.

Because Windows is a non-POSIX-compliant operating system, there are differences between
how Ansible interacts with them and the way Windows works. These guides will highlight 
some of the differences between Linux/Unix hosts and hosts running Windows.

.. toctree::
   :maxdepth: 2

   windows_setup
   windows_winrm
   windows_usage
   windows_dsc
   windows_faq
